package com.gonval.precioselectricidad.activities;

import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Date;

import android.app.Dialog;
import android.app.Notification;
import android.app.NotificationManager;
import android.app.PendingIntent;
import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.os.AsyncTask;
import android.support.v4.app.NotificationCompat;

import com.gonval.precioselectricidad.R;
import com.gonval.precioselectricidad.beans.ItemPrice;
import com.gonval.precioselectricidad.database.DataBaseHelper;
import com.gonval.precioselectricidad.database.DataBaseManager;
import com.gonval.precioselectricidad.database.PricesDAO;
import com.gonval.precioselectricidad.util.Csvreader;
import com.gonval.precioselectricidad.util.UtilTime;

public class HttpTask extends AsyncTask<Void, Void, Boolean[]> {
	
	private final int NOTIFICATION_ID = 1;
	private final int BD_VERSION = 1;
	
	private Boolean firstConnection;
	private Boolean firstDayMonth = false;
	private Context context;
	private Dialog loadingDialog;
	private MainActivity activity;
	private DataBaseHelper dbService;
	
	public HttpTask(Boolean firstConnection, Context context, MainActivity activity){
		this.firstConnection = firstConnection;
		this.context = context; 
		this.activity = activity;
	}
	public HttpTask(Boolean firstConnection, Context context, Boolean firstDayMonth){
		this.firstConnection = firstConnection;
		this.context = context; 
		this.firstDayMonth = firstDayMonth;
	}
	@Override
    protected void onPreExecute() {
        super.onPreExecute();
        if (firstConnection == true)
        	loadingDialog = ProgressDialog.show(context, "Espere por favor", "Sincronizándo datos...");
    }

	protected Boolean[] doInBackground(Void... arg0) {

		dbService = new DataBaseHelper(context, BD_VERSION);
		DataBaseManager.initializeInstance(dbService);
		PricesDAO dao = new PricesDAO();
		Csvreader csvreader = new Csvreader();
		boolean resultToday = false;
		boolean resultTomorrow = false;
		Date today = UtilTime.getToday();
		Date tomorrow = UtilTime.getTomorrow();
		
		SimpleDateFormat df = new SimpleDateFormat("dd/MM/yyyy");
		String dayStr = df.format(tomorrow);
		if (firstConnection == true || firstDayMonth == true)
			 resultToday = csvreader.getPricesFromWeb(context, today);
		ArrayList<ItemPrice> listPrices = dao.getPricesDay(dayStr);
		if(listPrices.size() == 0)
			resultTomorrow = csvreader.getPricesFromWeb(context, tomorrow);

		Boolean[] arrayResults = new Boolean[2];
		arrayResults[0] = resultToday;
		arrayResults[1] = resultTomorrow;
		
		return arrayResults;
	}
	
	protected void onPostExecute(Boolean[] arrayResults) {

		if(arrayResults[0] == true && arrayResults[1]==true){
			UtilTime.cancelAlarm(context);
			UtilTime.setAlarmTomorrow(context);
			
			if(firstDayMonth == true){
				if(dbService.getNotificationStatus()==1)
					triggerNotification();
			}
			else{
				if(activity!=null)
					activity.loadFragment();
				loadingDialog.dismiss();
			}
		}else if(arrayResults[0] == true && arrayResults[1]==false){
			if(activity!=null)
				activity.loadFragment();
			loadingDialog.dismiss();
			UtilTime.setAlarm(context);
			
		}else if(arrayResults[0] == false && arrayResults[1]==true){
			UtilTime.cancelAlarm(context);
			UtilTime.setAlarmTomorrow(context);
			if(dbService.getNotificationStatus()==1)
				triggerNotification();
		}
	}
	
	private void triggerNotification() {
		Intent i = new Intent(context, MainActivity.class);
		i.putExtra("notificationID", NOTIFICATION_ID);
		PendingIntent pendingIntent = PendingIntent.getActivity(context, 0, i, 0);
		NotificationManager nm = (NotificationManager) context.getSystemService(Context.NOTIFICATION_SERVICE);

		CharSequence contentTitle = "Precios Electricidad";
		CharSequence contentText = "Toque para ver la lista de precios disponible";
		Notification noti = new NotificationCompat.Builder(context)
				.setContentIntent(pendingIntent).setContentTitle(contentTitle)
				.setContentText(contentText)
				.setSmallIcon(R.drawable.ic_launcher)
				.addAction(R.drawable.ic_launcher, contentTitle, pendingIntent)
				.setVibrate(new long[] {100, 250, 100, 500})
				.build();
		nm.notify(NOTIFICATION_ID, noti);
	}
}
