package com.gonval.precioselectricidad.activities;

import java.math.BigDecimal;
import java.math.RoundingMode;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Calendar;
import java.util.List;

import android.os.Bundle;
import android.support.v4.app.ListFragment;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ListView;

import com.gonval.precioselectricidad.R;
import com.gonval.precioselectricidad.adapters.PricesListViewAdapter;
import com.gonval.precioselectricidad.adapters.RecordPricesListViewAdapter;
import com.gonval.precioselectricidad.beans.ItemPrice;
import com.gonval.precioselectricidad.database.DataBaseHelper;
import com.gonval.precioselectricidad.database.DataBaseManager;
import com.gonval.precioselectricidad.database.PricesDAO;
import com.mobsandgeeks.adapters.Sectionizer;
import com.mobsandgeeks.adapters.SimpleSectionAdapter;

public class PricesListFragment extends ListFragment {

	public static int BD_VERSION = 1;
	private int fragmentNum;

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		if (getArguments() != null) {
			fragmentNum = getArguments().getInt("num");
		}
		setHasOptionsMenu(true);
	}

	@Override
	public View onCreateView(LayoutInflater inflater, ViewGroup container,
			Bundle savedInstanceState) {
		return inflater.inflate(R.layout.activity_prices_day_list, container, false);
	}

	@Override
	public void onActivityCreated(Bundle savedInstanceState) {
		super.onActivityCreated(savedInstanceState);
	}

	@Override
	public void onResume() {
		super.onResume();
		showPrices();
	}

	public void showPrices() {
		
		DataBaseHelper dbService = new DataBaseHelper(getActivity(), BD_VERSION);
		DataBaseManager.initializeInstance(dbService);
		PricesDAO dao = new PricesDAO();
		String day = "";
		java.util.Date requiredDate = null;
		SimpleDateFormat df = new SimpleDateFormat("dd/MM/yyyy");
		Calendar cal = Calendar.getInstance();
		if (fragmentNum == 0) {
			requiredDate = cal.getTime();
		} else if (fragmentNum == 1) {
			cal.add(Calendar.DATE, 1);
			requiredDate = cal.getTime();
		}
		if (requiredDate != null)
			day = df.format(requiredDate);

		ArrayList<ItemPrice> listPrices = dao.getPricesDay(day);
		ArrayList<ItemPrice> minPrices = dao.getMinPricesDay(day);
		ArrayList<ItemPrice> maxPrices = dao.getMaxPricesDay(day);

		if (listPrices.size() > 0) {

			String[] times = new String[listPrices.size()];
			String[] prices = new String[listPrices.size()];
			String[] dates = new String[listPrices.size()];
			int[] min = new int[listPrices.size()];
			int[] max = new int[listPrices.size()];

			List<ItemPrice> rowItems;
			for (int i = 0; i < listPrices.size(); i++) {

				dates[i] = listPrices.get(i).getDate();
				times[i] = listPrices.get(i).getTime();
				prices[i] = String.format("%.4f", round(Double.parseDouble(listPrices.get(i).getPrice())/1000, 4));
				if(fragmentNum != 2){
					min[i] = minPrices.get(i).getMin();
					max[i] = maxPrices.get(i).getMax();
				}
			}
			rowItems = new ArrayList<ItemPrice>();
			for (int i = 0; i < times.length; i++) {
				ItemPrice item ;
				if(fragmentNum != 2){
					item = new ItemPrice(dates[i],times[i], prices[i], max[i], min[i]);
				}else{
					item = new ItemPrice(dates[i],times[i], prices[i]);
				}
				rowItems.add(item);
			}

			ListView listView = getListView();
			if (fragmentNum == 2) {

				RecordPricesListViewAdapter adapterRecordPrices = new RecordPricesListViewAdapter(
						getActivity(), R.layout.content, rowItems);

				Sectionizer<ItemPrice> sectionizer = (Sectionizer<ItemPrice>) new PricesSectionizer();

				SimpleSectionAdapter<ItemPrice> sectionAdapter = new SimpleSectionAdapter<ItemPrice>(
						getActivity(), adapterRecordPrices, R.layout.header,
						R.id.date, sectionizer);
				listView.setAdapter(sectionAdapter);

			} else {
				PricesListViewAdapter adapter = new PricesListViewAdapter(getActivity(),
						R.layout.content, rowItems);
				listView.setAdapter(adapter);
			}
		}
		dbService.close();
	}
	public static double round(double value, int places) {
	    if (places < 0) throw new IllegalArgumentException();

	    BigDecimal bd = new BigDecimal(value);
	    bd = bd.setScale(places, RoundingMode.HALF_UP);
	    return bd.doubleValue();
	}
}
